@@ -3,8 +3,8 @@ function(filename="model.bug", dir=getwd())
 {
     old.dir <- getwd()
     setwd(dir)
+    on.exit(setwd(old.dir))
     clean <- file.remove(filename)
-    setwd(old.dir)
     invisible(clean)
 }
 
