@@ -19,12 +19,11 @@ flavour = c("jags", "bugs"), ...)
     if (times < 2)
         stop("no need for parallel computing")
     ## globel options
-    rhat.opts <- getOption("dclone.rhat")
-    trace <- getOption("dclone.verbose")
+    rhat.opts <- getOption("dcoptions")$rhat
+    trace <- getOption("dcoptions")$verbose
     ## evaluate inits
     if (missing(inits))
         inits <- NULL
-
     ## write model
     if (is.function(model) || inherits(model, "custommodel")) {
         if (is.function(model))
@@ -58,10 +57,10 @@ flavour = c("jags", "bugs"), ...)
     rng <- c("Wichmann-Hill", "Marsaglia-Multicarry",
         "Super-Duper", "Mersenne-Twister")
     rng <- rep(rng, length(cl))[1:length(cl)]
-    balancing <- if (getOption("dclone.LB"))
+    balancing <- if (getOption("dcoptions")$LB)
         "size" else "both"
     pmod <- snowWrapper(cl, k, dcparallel, cldata, lib="dclone", 
-        balancing=balancing, size=k, dir=getwd(), ...)
+        balancing=balancing, size=k, dir=getwd(), set.rng=TRUE, ...)
     mod <- pmod[[times]]
 
     ## dctable
