@@ -1,6 +1,7 @@
 snowWrapper <-
 function(cl, seq, fun, cldata, name="cldata", lib=NULL, evalq=NULL,
-size = 1, balancing=c("none", "load", "size", "both"), dir = getwd(), ...)
+size = 1, balancing=c("none", "load", "size", "both"), dir = getwd(), 
+set.rng=TRUE, ...)
 {
     balancing <- match.arg(balancing)
     ## if object name exists in global env, make a copy as tmp, and put back in the end
@@ -14,6 +15,10 @@ size = 1, balancing=c("none", "load", "size", "both"), dir = getwd(), ...)
         for (i in lib)
             eval(parse(text=paste("clusterEvalQ(cl, library(", i, "))")))
     }
+    ## set seed on each worker 
+    if (set.rng) {
+        clusterSetupRNG(cl, type = getOption("dcoptions")$RNG)
+    }
     ## sets common working directory
     eval(parse(text=paste("clusterEvalQ(cl, setwd('", dir, "'))", sep="")))
     ## evaluates literal expressions if needed
